@@ -11,7 +11,7 @@
 
 #include <kuser.h>
 #include <kstandarddirs.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 #include <tqfileinfo.h>
 #include <tqdatetime.h>
