@@ -18,7 +18,7 @@
 
 class MagicLabel : TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   private:
